@@ -47,7 +47,7 @@
    Contributing author: Mike Brown (SNL)
 ------------------------------------------------------------------------- */
 
-#include "stdlib.h"
+#include <stdlib.h>
 #include "atom_vec_ellipsoid.h"
 #include "math_extra.h"
 #include "atom.h"
