@@ -33,23 +33,26 @@
 -------------------------------------------------------------------------
     Contributing author and copyright for this file:
 
-    Christoph Kloss (DCS Computing GmbH, Linz, JKU Linz)
+    Christoph Kloss (DCS Computing GmbH, Linz)
+    Christoph Kloss (JKU Linz)
     Philippe Seil (JKU Linz)
+    Richard Berger (JKU Linz)
 
     Copyright 2012-     DCS Computing GmbH, Linz
-    Copyright 2009-2012 JKU Linz
+    Copyright 2009-2015 JKU Linz
 ------------------------------------------------------------------------- */
 
 #include "bounding_box.h"
+#include <algorithm>
 
 namespace LAMMPS_NS
 {
 
   BoundingBox::BoundingBox()
-  : xLo(0.), xHi(0.), yLo(0.), yHi(0.), zLo(0.), zHi(0.), initGiven(false)
+  : xLo(0.), xHi(0.), yLo(0.), yHi(0.), zLo(0.), zHi(0.), initGiven(false), dirty(true)
   {}
   BoundingBox::BoundingBox(double xLo_, double xHi_, double yLo_, double yHi_, double zLo_, double zHi_)
-  : xLo(xLo_), xHi(xHi_), yLo(yLo_), yHi(yHi_), zLo(zLo_), zHi(zHi_), initGiven(true)
+  : xLo(xLo_), xHi(xHi_), yLo(yLo_), yHi(yHi_), zLo(zLo_), zHi(zHi_), initGiven(true), dirty(true)
   {}
 
   BoundingBox::~BoundingBox()
@@ -61,6 +64,27 @@ namespace LAMMPS_NS
     yLo = 0.; yHi = 0.;
     zLo = 0.; zHi = 0.;
     initGiven = false;
+    dirty = true;
+  }
+
+  void BoundingBox::extendByDelta(double delta)
+  {
+    xLo = xLo-delta;
+    yLo = yLo-delta;
+    zLo = zLo-delta;
+    xHi = xHi+delta;
+    yHi = yHi+delta;
+    zHi = zHi+delta;
+  }
+
+  void BoundingBox::extrude(double length, const double * vec)
+  {
+    xLo = std::min(xLo, (xLo + length * vec[0]));
+    yLo = std::min(yLo, (yLo + length * vec[1]));
+    zLo = std::min(zLo, (zLo + length * vec[2]));
+    xHi = std::max(xHi, (xHi + length * vec[0]));
+    yHi = std::max(yHi, (yHi + length * vec[1]));
+    zHi = std::max(zHi, (zHi + length * vec[2]));
   }
 
 } /* namespace LAMMPS_NS */
