@@ -55,7 +55,7 @@
 
 #include "lmptype.h"
 #include <mpi.h>
-#include <math.h>
+#include <cmath>
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
