@@ -58,10 +58,10 @@ using namespace LAMMPS_NS;
 
 /* ---------------------------------------------------------------------- */
 
-ComputeKEAtom::ComputeKEAtom(LAMMPS *lmp, int narg, char **arg) :
-  Compute(lmp, narg, arg)
+ComputeKEAtom::ComputeKEAtom(LAMMPS *lmp, int &iarg, int narg, char **arg) :
+  Compute(lmp, iarg, narg, arg)
 {
-  if (narg != 3) error->all(FLERR,"Illegal compute ke/atom command");
+  if (narg != iarg) error->all(FLERR,"Illegal compute ke/atom command");
 
   peratom_flag = 1;
   size_peratom_cols = 0;
