@@ -70,7 +70,7 @@ class ComputePairGranLocal : public Compute {
   void compute_local();
   double memory_usage();
   void reference_deleted();
-  virtual void add_pair(int i,int j,double fx,double fy,double fz,double tor1,double tor2,double tor3,double *hist);
+  virtual void add_pair(int i,int j,double fx,double fy,double fz,double tor1,double tor2,double tor3,double *hist, const double * const contact_point);
   virtual void add_heat(int i,int j,double hf);
   virtual void add_wall_1(int iFMG,int iTri,int iP,double *contact_point,double *v_wall);
   virtual void add_wall_2(int i,double fx,double fy,double fz,double tor1,double tor2,double tor3,double *hist,double rsq, double *normal_);
@@ -147,6 +147,16 @@ class ComputePairGranLocal : public Compute {
     //return offset_history() + get_history_offset("contact_point_offset");
   }
 
+  virtual int offset_ms_id1()
+  {
+    return (msidflag > 0 ?   posflag*6+velflag*6+idflag*3+fflag*3+fnflag*3+ftflag*3+torqueflag*3+torquenflag*3+torquetflag*3+histflag*dnum+areaflag*1 + deltaflag*1 + heatflag*1 + cpflag*3 : -1);
+  }
+
+  virtual int offset_ms_id2()
+  {
+    return (msidflag > 0 ?   posflag*6+velflag*6+idflag*3+fflag*3+fnflag*3+ftflag*3+torqueflag*3+torquenflag*3+torquetflag*3+histflag*dnum+areaflag*1 + deltaflag*1 + heatflag*1 + cpflag*3 +1 : -1);
+  }
+
  protected:
 
   int nvalues;      // number of double values per entry
@@ -170,10 +180,11 @@ class ComputePairGranLocal : public Compute {
   class PairGran *pairgran;
   class FixHeatGranCond *fixheat;
   class FixWallGran *fixwall;
+  class FixMultisphere *fix_ms;
 
   int ipair;
 
-  int posflag,velflag,idflag,fflag,fnflag,ftflag,torqueflag,torquenflag,torquetflag,histflag,areaflag,deltaflag,heatflag,cpflag;
+  int posflag,velflag,idflag,fflag,fnflag,ftflag,torqueflag,torquenflag,torquetflag,histflag,areaflag,deltaflag,heatflag,cpflag,msidflag;
 
   bool   verbose;
 
