@@ -145,14 +145,14 @@ using namespace LAMMPS_NS;
    rotate all properties, applies to vector and multivector only
   ------------------------------------------------------------------------- */
 
-  void CustomValueTracker::rotate(double *totalQ,double *dQ)
+  void CustomValueTracker::rotate(const double * const totalQ, const double * const dQ)
   {
       
       elementProperties_.rotate(dQ);
       globalProperties_.rotate(totalQ);
   }
 
-  void CustomValueTracker::rotate(double *dQ)
+  void CustomValueTracker::rotate(const double * const dQ)
   {
       
       elementProperties_.rotate(dQ);
@@ -174,14 +174,14 @@ using namespace LAMMPS_NS;
    move all properties
   ------------------------------------------------------------------------- */
 
-  void CustomValueTracker::move(double *vecTotal, double *vecIncremental)
+  void CustomValueTracker::move(const double * const vecTotal, const double * const vecIncremental)
   {
       
       elementProperties_.move(vecIncremental);
       globalProperties_.move(vecTotal);
   }
 
-  void CustomValueTracker::move(double *vecIncremental)
+  void CustomValueTracker::move(const double * const vecIncremental)
   {
       
       elementProperties_.move(vecIncremental);
