@@ -221,8 +221,8 @@ class DumpCustom : public Dump {
   void pack_quat2(int);
   void pack_quat3(int);
   void pack_quat4(int);
-  void pack_roundness1(int);
-  void pack_roundness2(int);
+  void pack_blockiness1(int);
+  void pack_blockiness2(int);
   void pack_inertiax(int);
   void pack_inertiay(int);
   void pack_inertiaz(int);
