@@ -39,7 +39,7 @@
     Copyright 2009-2012 JKU Linz
 ------------------------------------------------------------------------- */
 
-#include "string.h"
+#include <string.h>
 #include "dump_decomposition_vtk.h"
 #include "domain.h"
 #include "atom.h"
@@ -50,9 +50,10 @@
 #include "modify.h"
 #include "comm.h"
 
-using namespace LAMMPS_NS;
+// include last to ensure correct macros
+#include "domain_definitions.h"
 
-#define BIG      1.0e30
+using namespace LAMMPS_NS;
 
 /* ---------------------------------------------------------------------- */
 
