@@ -43,7 +43,7 @@
     the GNU General Public License.
 ------------------------------------------------------------------------- */
 
-#include <math.h>
+#include <cmath>
 #include "ctype.h"
 #include <stdlib.h>
 #include <string.h>
@@ -328,9 +328,7 @@ DumpImage::DumpImage(LAMMPS *lmp, int narg, char **arg) :
       if (strcmp(arg[iarg+1],"yes") == 0) image->ssao = YES;
       else if (strcmp(arg[iarg+1],"no") == 0) image->ssao = NO;
       else error->all(FLERR,"Illegal dump image command");
-      int seed = force->inumeric(FLERR,arg[iarg+2]);
-      if (seed <= 0) error->all(FLERR,"Illegal dump image command");
-      image->seed = seed;
+      image->setSeed(arg[iarg+2]);
       double ssaoint = force->numeric(FLERR,arg[iarg+3]);
       if (ssaoint < 0.0 || ssaoint > 1.0)
         error->all(FLERR,"Illegal dump image command");
