@@ -52,7 +52,7 @@ FixStyle(ave/spatial,FixAveSpatial)
 #ifndef LMP_FIX_AVE_SPATIAL_H
 #define LMP_FIX_AVE_SPATIAL_H
 
-#include "stdio.h"
+#include <stdio.h>
 #include "fix.h"
 
 namespace LAMMPS_NS {
