@@ -42,7 +42,7 @@
 #include <stdlib.h>
 #include "atom.h"
 #include "update.h"
-#include <math.h>
+#include <cmath>
 #include "error.h"
 #include "fix_check_timestep_sph.h"
 #include "fix_property_global.h"
