@@ -49,7 +49,7 @@
 
 #include <string.h>
 #include <stdlib.h>
-#include <math.h>
+#include <cmath>
 #include "fix_deform.h"
 #include "atom.h"
 #include "update.h"
