@@ -46,7 +46,7 @@
 
 #include <string.h>
 #include <stdlib.h>
-#include <math.h>
+#include <cmath>
 #include "fix_deform_check.h"
 #include "atom.h"
 #include "update.h"
