@@ -584,12 +584,12 @@ void FixMeshSurface::createWallNeighList(int igrp)
     char *neighlist_name = new char[strlen(id)+1+20];
     sprintf(neighlist_name,"wall_neighlist_%s",id);
 
-    char **fixarg = new char*[4];
+    const char *fixarg[4];
     fixarg[0]= neighlist_name;
-    fixarg[1]= (char *) "all";
-    fixarg[2]= (char *) "neighlist/mesh";
+    fixarg[1]= "all";
+    fixarg[2]= "neighlist/mesh";
     fixarg[3]= id;
-    modify->add_fix(4,fixarg);
+    modify->add_fix(4,const_cast<char**>(fixarg));
 
     fix_mesh_neighlist_ =
         static_cast<FixNeighlistMesh*>(modify->find_fix_id(neighlist_name));
@@ -602,7 +602,6 @@ void FixMeshSurface::createWallNeighList(int igrp)
     // neighlist build will use this: merging of wall and mesh groupbit
     fix_mesh_neighlist_->groupbit_wall_mesh = group->bitmask[igroup] | igrp;
 
-    delete []fixarg;
     delete []neighlist_name;
 
     /*
@@ -635,13 +634,13 @@ class FixNeighlistMesh* FixMeshSurface::createOtherNeighList(int igrp,const char
     if(modify->find_fix_id(neighlist_name))
         error->fix_error(FLERR,this,"must not use the same mesh for fix massflow/mesh with same group");
 
-    char **fixarg = new char*[5];
+    const char *fixarg[5];
     fixarg[0]= neighlist_name;
-    fixarg[1]= (char *) "all";
-    fixarg[2]= (char *) "neighlist/mesh";
+    fixarg[1]= "all";
+    fixarg[2]= "neighlist/mesh";
     fixarg[3]= id;
-    fixarg[4]= (char *) "other_yes";
-    modify->add_fix(5,fixarg);
+    fixarg[4]= "other_yes";
+    modify->add_fix(5,const_cast<char**>(fixarg));
 
     neighlist =
         static_cast<FixNeighlistMesh*>(modify->find_fix_id(neighlist_name));
@@ -652,7 +651,6 @@ class FixNeighlistMesh* FixMeshSurface::createOtherNeighList(int igrp,const char
 
     list_other_neighlist_[neighlist_name] = neighlist;
 
-    delete []fixarg;
     delete []neighlist_name;
 
     return neighlist;
@@ -699,18 +697,17 @@ void FixMeshSurface::createContactHistory(int dnum)
     char dnum_char[10];
     sprintf(dnum_char,"%d",dnum);
 
-    char **fixarg = new char*[5];
+    const char *fixarg[5];
     fixarg[0] = contacthist_name;
-    fixarg[1] = (char *) "all";
-    fixarg[2] = (char *) "contacthistory/mesh";
-    fixarg[3]= dnum_char;
+    fixarg[1] = "all";
+    fixarg[2] = "contacthistory/mesh";
+    fixarg[3] = dnum_char;
     fixarg[4] = my_id;
 
-    modify->add_fix(5,fixarg);
+    modify->add_fix(5,const_cast<char**>(fixarg));
 
     fix_contact_history_mesh_ = static_cast<FixContactHistoryMesh*>(modify->find_fix_id(contacthist_name));
 
-    delete []fixarg;
     delete []contacthist_name;
     delete []my_id;
 }
@@ -733,70 +730,68 @@ void FixMeshSurface::createMeshforceContact()
 {
     if(fix_meshforce_contact_) return;
 
-    char **fixarg = new char*[19];
+    const char *fixarg[19];
     char fixid[200],propertyid[200];
     sprintf(fixid,"contactforces_%s",id);
     sprintf(propertyid,"contactforces_%s",id);
-    fixarg[0]=(char *) fixid;
-    fixarg[1]=(char *) "all";
-    fixarg[2]=(char *) "contactproperty/atom/wall";
-    fixarg[3]=(char *) propertyid;
-    fixarg[4]=(char *) "6";
-    fixarg[5]=(char *) "fx";
-    fixarg[6]=(char *) "0";
-    fixarg[7]=(char *) "fy";
-    fixarg[8]=(char *) "0";
-    fixarg[9]=(char *) "fz";
-    fixarg[10]=(char *) "0";
-    fixarg[11]=(char *) "tx";
-    fixarg[12]=(char *) "0";
-    fixarg[13]=(char *) "ty";
-    fixarg[14]=(char *) "0";
-    fixarg[15]=(char *) "tz";
-    fixarg[16]=(char *) "0";
-    fixarg[17]=(char *) "mesh";
-    fixarg[18]=(char *) this->id;
-    modify->add_fix(19,fixarg);
+    fixarg[0]=fixid;
+    fixarg[1]="all";
+    fixarg[2]="contactproperty/atom/wall";
+    fixarg[3]=propertyid;
+    fixarg[4]="6";
+    fixarg[5]="fx";
+    fixarg[6]="0";
+    fixarg[7]="fy";
+    fixarg[8]="0";
+    fixarg[9]="fz";
+    fixarg[10]="0";
+    fixarg[11]="tx";
+    fixarg[12]="0";
+    fixarg[13]="ty";
+    fixarg[14]="0";
+    fixarg[15]="tz";
+    fixarg[16]="0";
+    fixarg[17]="mesh";
+    fixarg[18]=this->id;
+    modify->add_fix(19,const_cast<char**>(fixarg));
     fix_meshforce_contact_ = static_cast<FixContactPropertyAtomWall*>(modify->find_fix_id(fixid));
-    delete []fixarg;
 }
 
 void FixMeshSurface::createMeshforceContactStress()
 {
     if(fix_meshforce_contact_stress_) return;
 
-    char **fixarg = new char*[25];
+    const char *fixarg[25];
     char fixid[200],propertyid[200];
     sprintf(fixid,"contactforces_stress_%s",id);
     sprintf(propertyid,"contactforces_stress_%s",id);
-    fixarg[0]=(char *) fixid;
-    fixarg[1]=(char *) "all";
-    fixarg[2]=(char *) "contactproperty/atom/wall";
-    fixarg[3]=(char *) propertyid;
-    fixarg[4]=(char *) "9";
-    fixarg[5]=(char *) "fx";
-    fixarg[6]=(char *) "0";
-    fixarg[7]=(char *) "fy";
-    fixarg[8]=(char *) "0";
-    fixarg[9]=(char *) "fz";
-    fixarg[10]=(char *) "0";
-    fixarg[11]=(char *) "deltax";
-    fixarg[12]=(char *) "0";
-    fixarg[13]=(char *) "deltay";
-    fixarg[14]=(char *) "0";
-    fixarg[15]=(char *) "deltaz";
-    fixarg[16]=(char *) "0";
-    fixarg[17]=(char *) "vx";
-    fixarg[18]=(char *) "0";
-    fixarg[19]=(char *) "vy";
-    fixarg[20]=(char *) "0";
-    fixarg[21]=(char *) "vz";
-    fixarg[22]=(char *) "0";
-    fixarg[23]=(char *) "mesh";
-    fixarg[24]=(char *) this->id;
-    modify->add_fix(25,fixarg);
+    fixarg[0]=fixid;
+    fixarg[1]="all";
+    fixarg[2]="contactproperty/atom/wall";
+    fixarg[3]=propertyid;
+    fixarg[4]="9";
+    fixarg[5]="fx";
+    fixarg[6]="0";
+    fixarg[7]="fy";
+    fixarg[8]="0";
+    fixarg[9]="fz";
+    fixarg[10]="0";
+    fixarg[11]="deltax";
+    fixarg[12]="0";
+    fixarg[13]="deltay";
+    fixarg[14]="0";
+    fixarg[15]="deltaz";
+    fixarg[16]="0";
+    fixarg[17]="vx";
+    fixarg[18]="0";
+    fixarg[19]="vy";
+    fixarg[20]="0";
+    fixarg[21]="vz";
+    fixarg[22]="0";
+    fixarg[23]="mesh";
+    fixarg[24]=this->id;
+    modify->add_fix(25,const_cast<char**>(fixarg));
     fix_meshforce_contact_stress_ = static_cast<FixContactPropertyAtomWall*>(modify->find_fix_id(fixid));
-    delete []fixarg;
 }
 
 void FixMeshSurface::createMulticontactData()
@@ -806,29 +801,28 @@ void FixMeshSurface::createMulticontactData()
     // create a new per contact property which will contain the data for the computation according to Brodu et. al. 2016
     // surfPosIJ will contain the position of the contact surface ij, realtive to position i
     // normalForce will contain the normal component of the contact force
-    char **fixarg = new char*[17];
+    const char *fixarg[17];
     char fixid[200];
     sprintf(fixid,"multicontactData_%s",id);
     fixarg[0]=fixid;
-    fixarg[1]=(char *) "all";
-    fixarg[2]=(char *) "contactproperty/atom/wall";
+    fixarg[1]="all";
+    fixarg[2]="contactproperty/atom/wall";
     fixarg[3]=fixid;
-    fixarg[4]=(char *) "4";
-    fixarg[5]=(char *) "surfPosIJ_x";
-    fixarg[6]=(char *) "0";
-    fixarg[7]=(char *) "surfPosIJ_y";
-    fixarg[8]=(char *) "0";
-    fixarg[9]=(char *) "surfPosIJ_z";
-    fixarg[10]=(char *) "0";
-    fixarg[11]=(char *) "normalForce";
-    fixarg[12]=(char *) "0";
-    fixarg[13]=(char *) "mesh";
-    fixarg[14]=(char *) id;
-    fixarg[15]=(char *) "reset";
-    fixarg[16]=(char *) "no";
-    modify->add_fix(17,fixarg);
+    fixarg[4]="4";
+    fixarg[5]="surfPosIJ_x";
+    fixarg[6]="0";
+    fixarg[7]="surfPosIJ_y";
+    fixarg[8]="0";
+    fixarg[9]="surfPosIJ_z";
+    fixarg[10]="0";
+    fixarg[11]="normalForce";
+    fixarg[12]="0";
+    fixarg[13]="mesh";
+    fixarg[14]=id;
+    fixarg[15]="reset";
+    fixarg[16]="no";
+    modify->add_fix(17,const_cast<char**>(fixarg));
     fix_mesh_multicontact_data_ = static_cast<FixContactPropertyAtomWall*>(modify->find_fix_id(fixid));
-    delete []fixarg;
 }
 
 void FixMeshSurface::deleteMeshforceContact()
