@@ -34,8 +34,8 @@
     Contributing author and copyright for this file:
 
     Christoph Kloss (JKU Linz, DCS Computing GmbH, Linz)
-    Philippe Seil (JKU Linz)
-    Arno Mayerhofer (CFDEMresearch GmbH)
+    Philippe Seil   (JKU Linz)
+    Arno Mayrhofer  (CFDEMresearch GmbH, DCS Computing GmbH, Linz)
 
     Copyright 2012-     DCS Computing GmbH, Linz
     Copyright 2009-2012 JKU Linz
@@ -58,6 +58,12 @@ FixStyle(mesh/surface/planar,FixMeshSurface)
 #include "fix_contact_property_atom.h"
 #include "fix_neighlist_mesh.h"
 #include "custom_value_tracker.h"
+#include "mesh_module.h"
+#include <map>
+#include <vector>
+#include <string>
+#include <algorithm>
+#include <cstddef>
 
 namespace LAMMPS_NS
 {
@@ -68,17 +74,24 @@ namespace LAMMPS_NS
         FixMeshSurface(LAMMPS *lmp, int narg, char **arg);
         virtual ~FixMeshSurface();
 
+        virtual void post_create_pre_restart();
         virtual void post_create();
         virtual void pre_delete(bool unfixflag);
 
-        virtual void init() {FixMesh::init();}
-        virtual void setup(int vflag) {}
+        virtual void init();
+        virtual void setup(int vflag);
 
         virtual int setmask();
         virtual void setup_pre_force(int);
 
         virtual void pre_force(int);
+        virtual void initial_integrate(int);
         virtual void final_integrate();
+        virtual void end_of_step();
+
+        virtual int modify_param(int narg, char **arg);
+
+        virtual double compute_vector (int);
 
         virtual void createWallNeighList(int igrp);
         virtual class FixNeighlistMesh* createOtherNeighList(int igrp,const char *nId);
@@ -89,14 +102,18 @@ namespace LAMMPS_NS
         void createMulticontactData();
 
         void deleteWallNeighList();
+        void deleteOtherNeighList(const char *nId);
+        void deleteAllOtherNeighList();
         void deleteContactHistory();
         void deleteMeshforceContact();
 
         void deleteMeshforceContactStress();
         void deleteMeshMulticontactData();
 
-        inline bool trackStress()
-        {return stress_flag_;}
+        MeshModule* get_module(std::string name);
+        void add_particle_contribution(int ip, double *frc, double *delta, int iTri, double *v_wall);
+
+        bool trackStress();
 
         inline int atomTypeWall()
         { return atom_type_mesh_;}
@@ -110,6 +127,9 @@ namespace LAMMPS_NS
         inline bool hasNeighList()
         { return fix_mesh_neighlist_?true:false; }
 
+        inline bool hasOtherNeighList()
+        { return list_other_neighlist_.size() > 0; }
+
         inline class FixContactPropertyAtomWall* meshforceContact()
         { return fix_meshforce_contact_;}
 
@@ -131,16 +151,43 @@ namespace LAMMPS_NS
         void dumpRemove()
         { n_dump_active_--; }
 
+        inline int get_groupbit() const
+        { return groupbit; }
+
+        inline int get_nevery() const
+        { return nevery; }
+
+        inline bigint* get_next_reneighbor_ptr()
+        { return &next_reneighbor; }
+
+        void set_global_freq(const unsigned int global_freq_)
+        { global_freq = global_freq_; }
+
+        void set_extvector(const unsigned int extvector_)
+        { extvector = extvector_; }
+
+        void set_time_depend(const unsigned int time_depend_)
+        { time_depend = time_depend_; }
+
+        void set_nevery(const unsigned int nevery_)
+        { nevery = nevery_; }
+
       protected:
 
+        int getCreateMeshTriCount()
+        { return extrusion_tri_count_; }
+
+        double * getCreateMeshTriNode(const int i)
+        { return &(extrusion_tri_nodes_[i*3]); }
+
         class FixContactHistoryMesh *fix_contact_history_mesh_;
         class FixNeighlistMesh *fix_mesh_neighlist_;
         class FixContactPropertyAtomWall *fix_meshforce_contact_;
         class FixContactPropertyAtomWall *fix_meshforce_contact_stress_;
         class FixContactPropertyAtomWall *fix_mesh_multicontact_data_;
 
-        // flag for stressanalysis
-        bool stress_flag_;
+        // list of neighbor lists created by createOtherNeighList
+        std::map<std::string, FixNeighlistMesh*> list_other_neighlist_;
 
       private:
 
@@ -152,12 +199,17 @@ namespace LAMMPS_NS
         // surface velocity
         bool velFlag_;
         double vSurf_[3];
+        char *vSurfStrX_, *vSurfStrY_, *vSurfStrZ_;
+        int vSurfVarX_, vSurfVarY_, vSurfVarZ_;
+        int vSurfStyleX_, vSurfStyleY_, vSurfStyleZ_;
 
         // rotational surf vel
         bool angVelFlag_;
         double origin_[3];
         double axis_[3];
         double omegaSurf_;
+        char *omegaStr_;
+        int omegaVar_, omegaStyle_;
 
         // flag if dump mesh/* or dump stl is active
         int n_dump_active_;
@@ -165,6 +217,20 @@ namespace LAMMPS_NS
         // mesh curvature
         double curvature_;
         bool curvature_tolerant_;
+
+        // extrude mesh
+        bool extrude_mesh_;
+        double extrusion_length_;
+        int extrusion_tri_count_;
+        double *extrusion_tri_nodes_;
+        bool extrusion_created_;
+
+        // active mesh modules
+        typedef MeshModule *(*MeshModuleCreator)(LAMMPS *lmp, int &iarg_, int narg, char **arg, FixMeshSurface *fix_mesh);
+        std::map<std::string, MeshModule*> active_mesh_modules;
+        std::vector<std::string> mesh_module_order;
+
+        template <typename T> static MeshModule *meshmodule_creator(LAMMPS *lmp, int &iarg_, int narg, char **arg, FixMeshSurface *fix_mesh);
   };
 
 } /* namespace LAMMPS_NS */
