@@ -48,7 +48,7 @@
                         Paul Crozier (SNL)
 ------------------------------------------------------------------------- */
 
-#include <math.h>
+#include <cmath>
 #include <stdlib.h>
 #include <string.h>
 #include "fix_spring_rg.h"
