@@ -93,6 +93,7 @@ Force::Force(LAMMPS *lmp) : Pointers(lmp), registry(lmp)
 
   coarsegraining_ = 1.0;
   error_coarsegraining_ = true;
+  warn_coarsegraining_ = false;
 
   pair = NULL;
   bond = NULL;
@@ -162,8 +163,8 @@ void Force::init()
   if (angle) angle->init();
   if (dihedral) dihedral->init();
   if (improper) improper->init();
-  if(cg_active() && atom->ntypes != int(coarsegrainingTypeBased_.size()))
-    error->warning(FLERR,"Coarse graining factor not specified for all atom types. will use maximum CG for unspecified atom types.\n\n");
+  if(cg_active() && warn_cg() && atom->ntypes != int(coarsegrainingTypeBased_.size()))
+    error->warningAll(FLERR,"Coarse graining factor not specified for all atom types. will use maximum CG for unspecified atom types.\n\n");
 }
 
 /* ----------------------------------------------------------------------
@@ -793,16 +794,28 @@ void Force::bounds(char *str, int nmax, int &nlo, int &nhi, int nmin)
 
 double Force::numeric(const char *file, const int line, const char *const str)
 {
-  int n = strlen(str);
-  for (int i = 0; i < n; i++) {
-    if (isdigit(str[i])) continue;
-    if (str[i] == '-' || str[i] == '+' || str[i] == '.') continue;
-    if (str[i] == 'e' || str[i] == 'E') continue;
-    error->all(file,line,"Expected floating point parameter "
-               "in input script or data file");
-  }
+    const unsigned int n = strlen(str);
+    char *dstr;
+    dstr = new char[n+1];
+    for (unsigned int i = 0; i < n; i++)
+    {
+        if (isdigit(str[i]) ||
+            str[i] == '-'   ||
+            str[i] == '+'   ||
+            str[i] == '.'   ||
+            str[i] == 'e'   ||
+            str[i] == 'E')
+            dstr[i] = str[i];
+        else if (str[i] == '\r' && i == n-1)
+            dstr[i] = '\0';
+        else
+            error->all(file, line, "Expected floating point parameter in input script or data file");
+    }
+    dstr[n] = '\0';
 
-  return atof(str);
+    const double val = atof(dstr);
+    delete [] dstr;
+    return val;
 }
 
 /* ----------------------------------------------------------------------
@@ -813,14 +826,23 @@ double Force::numeric(const char *file, const int line, const char *const str)
 
 int Force::inumeric(const char *file, const int line, const char *const str)
 {
-  int n = strlen(str);
-  for (int i = 0; i < n; i++) {
-    if (isdigit(str[i]) || str[i] == '-' || str[i] == '+') continue;
-    error->all(file,line,
-               "Expected integer parameter in input script or data file");
-  }
+    const unsigned int n = strlen(str);
+    char *istr;
+    istr = new char[n+1];
+    for (unsigned int i = 0; i < n; i++)
+    {
+        if (isdigit(str[i]) || str[i] == '-' || str[i] == '+')
+            istr[i] = str[i];
+        else if (str[i] == '\r' && i == n-1)
+            istr[i] = '\0';
+        else
+            error->all(file, line, "Expected integer parameter in input script or data file");
+    }
+    istr[n] = '\0';
 
-  return atoi(str);
+    const int val = atoi(istr);
+    delete [] istr;
+    return val;
 }
 
 /* ----------------------------------------------------------------------
