@@ -47,11 +47,11 @@
    Contributing author: Nathan Fabian (Sandia)
 ------------------------------------------------------------------------- */
 
-#include "mpi.h"
-#include "math.h"
+#include <mpi.h>
+#include <cmath>
 #include "ctype.h"
-#include "stdlib.h"
-#include "string.h"
+#include <stdlib.h>
+#include <string.h>
 #include "image.h"
 #include "math_extra.h"
 #include "random_mars.h"
@@ -282,7 +282,6 @@ void Image::view_params(double boxxlo, double boxxhi, double boxylo,
   // adjust strength of the SSAO
 
   if (ssao) {
-    if (!random) random = new RanMars(lmp,seed+me);
     SSAORadius = maxdel * 0.05 * ssaoint;
     SSAOSamples = static_cast<int> (8.0 + 32.0*ssaoint);
     SSAOJitter = MY_PI / 12;
@@ -1915,3 +1914,9 @@ double *ColorMap::value2color(double value)
 
   return NULL;
 }
+
+void Image::setSeed(char * seed_char)
+{
+    if (!random)
+        random = new RanMars(lmp, seed_char, true);
+}
