@@ -48,7 +48,7 @@ NORMAL_MODEL(HERTZ,hertz,3)
 #define NORMAL_MODEL_HERTZ_H_
 #include "global_properties.h"
 #include "fix_property_atom.h"
-#include <math.h>
+#include <cmath>
 #include "normal_model_base.h"
 #include "fix_mesh_surface.h"
 
@@ -108,6 +108,12 @@ namespace ContactModels
                 hsetup->add_history_value("elastic_force_normal_0", "1");
                 hsetup->add_history_value("elastic_force_normal_1", "1");
                 hsetup->add_history_value("elastic_force_normal_2", "1");
+                hsetup->add_history_value("elastic_torque_normal_i_0", "0");
+                hsetup->add_history_value("elastic_torque_normal_i_1", "0");
+                hsetup->add_history_value("elastic_torque_normal_i_2", "0");
+                hsetup->add_history_value("elastic_torque_normal_j_0", "0");
+                hsetup->add_history_value("elastic_torque_normal_j_1", "0");
+                hsetup->add_history_value("elastic_torque_normal_j_2", "0");
                 if (cmb->is_wall())
                     hsetup->add_history_value("elastic_potential_wall", "0");
                 cmb->add_history_offset("elastic_potential_normal", elastic_potential_offset_);
@@ -150,13 +156,8 @@ namespace ContactModels
       // enlarge contact distance flag in case of elastic energy computation
       // to ensure that surfaceClose is called after a contact
       if (elasticpotflag_)
-      {
           //set neighbor contact_distance_factor here
-          const char* neigharg[2];
-          neigharg[0] = "contact_distance_factor";
-          neigharg[1] = "1.01";
-          neighbor->modify_params(2,const_cast<char**>(neigharg));
-      }
+          neighbor->register_contact_dist_factor(1.01);
     }
 
     // effective exponent for stress-strain relationship
@@ -183,12 +184,18 @@ namespace ContactModels
                                       delta[1]*(elastic_energy[2]) +
                                       delta[2]*(elastic_energy[3]))*0.5
                                      // from previous half step
-                                     + elastic_energy[4];
-                elastic_energy[4] = 0.0;
+                                     + elastic_energy[10];
+                elastic_energy[10] = 0.0;
             }
             elastic_energy[1] = 0.0;
             elastic_energy[2] = 0.0;
             elastic_energy[3] = 0.0;
+            elastic_energy[4] = 0.0;
+            elastic_energy[5] = 0.0;
+            elastic_energy[6] = 0.0;
+            elastic_energy[7] = 0.0;
+            elastic_energy[8] = 0.0;
+            elastic_energy[9] = 0.0;
         }
     }
 
@@ -204,12 +211,8 @@ namespace ContactModels
       double reff = sidata.is_wall ? radi : (radi*radj/(radi+radj));
 
       #ifdef SUPERQUADRIC_ACTIVE_FLAG
-        if(sidata.is_non_spherical) {
-          if(sidata.is_wall)
-            reff = MathExtraLiggghtsNonspherical::get_effective_radius_wall(sidata, atom->roundness[sidata.i], error);
-          else
-            reff = MathExtraLiggghtsNonspherical::get_effective_radius(sidata, atom->roundness[sidata.i], atom->roundness[sidata.j], error);
-        }
+      if(sidata.is_non_spherical && atom->superquadric_flag)
+        reff = sidata.reff;
       #endif
       const double meff=sidata.meff;
 
@@ -297,9 +300,9 @@ namespace ContactModels
             {
                 double * const elastic_energy = &sidata.contact_history[elastic_potential_offset_];
                 // correct for wall influence
-                    double delta[3];
                 if (sidata.is_wall)
                 {
+                    double delta[3];
                     sidata.fix_mesh->triMesh()->get_global_vel(delta);
                     vectorScalarMult3D(delta, update->dt);
                     // -= because force is in opposite direction
@@ -309,14 +312,20 @@ namespace ContactModels
                                           delta[1]*elastic_energy[2] +
                                           delta[2]*elastic_energy[3])*0.5
                                          // from previous half step
-                                         + elastic_energy[4];
-                    elastic_energy[4] = -(delta[0]*Fn_contact*sidata.en[0] +
-                                          delta[1]*Fn_contact*sidata.en[1] +
-                                          delta[2]*Fn_contact*sidata.en[2])*0.5;
+                                         + elastic_energy[10];
+                    elastic_energy[10] = -(delta[0]*Fn_contact*sidata.en[0] +
+                                           delta[1]*Fn_contact*sidata.en[1] +
+                                           delta[2]*Fn_contact*sidata.en[2])*0.5;
                 }
                 elastic_energy[1] = -Fn_contact*sidata.en[0];
                 elastic_energy[2] = -Fn_contact*sidata.en[1];
                 elastic_energy[3] = -Fn_contact*sidata.en[2];
+                elastic_energy[4] = 0.0;
+                elastic_energy[5] = 0.0;
+                elastic_energy[6] = 0.0;
+                elastic_energy[7] = 0.0;
+                elastic_energy[8] = 0.0;
+                elastic_energy[9] = 0.0;
             }
             // compute increment in dissipated energy
             if (dissipatedflag_)
@@ -397,7 +406,8 @@ namespace ContactModels
 
     void surfacesClose(SurfacesCloseData &scdata, ForceData&, ForceData&)
     {
-        if (scdata.contact_flags) *scdata.contact_flags |= CONTACT_NORMAL_MODEL;
+        if (scdata.contact_flags)
+            *scdata.contact_flags |= CONTACT_NORMAL_MODEL;
         dissipateElasticPotential(scdata);
     }
 
