@@ -51,7 +51,7 @@
 #include "ctype.h"
 #include "float.h"
 #include "limits.h"
-#include <math.h>
+#include <cmath>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
