@@ -87,6 +87,7 @@ class Region : protected Pointers {
   inline int match(double *point) 
   { return match(point[0],point[1],point[2]);}
 
+  void prematch();
   int match(double, double, double);
   int surface(double, double, double, double);
 
@@ -125,6 +126,7 @@ class Region : protected Pointers {
   virtual int surface_interior(double *, double) = 0;
   virtual int surface_exterior(double *, double) = 0;
   virtual void shape_update() {}
+  virtual void pretransform();
 
  protected:
   void add_contact(int, double *, double, double, double);
