@@ -47,7 +47,7 @@
    Contributing author: Pim Schravendijk
 ------------------------------------------------------------------------- */
 
-#include <math.h>
+#include <cmath>
 #include <stdlib.h>
 #include <string.h>
 #include "region_cone.h"
@@ -55,9 +55,10 @@
 #include "error.h"
 #include "force.h"
 
-using namespace LAMMPS_NS;
+// include last to ensure correct macros
+#include "domain_definitions.h"
 
-#define BIG 1.0e20
+using namespace LAMMPS_NS;
 
 /* ---------------------------------------------------------------------- */
 
