@@ -43,7 +43,7 @@
     the GNU General Public License.
 ------------------------------------------------------------------------- */
 
-#include <math.h>
+#include <cmath>
 #include <stdlib.h>
 #include <string.h>
 #include "region_cylinder.h"
@@ -54,9 +54,11 @@
 #include "error.h"
 #include "force.h"
 
+// include last to ensure correct macros
+#include "domain_definitions.h"
+
 using namespace LAMMPS_NS;
 
-#define BIG 1.0e20
 enum{CONSTANT,VARIABLE};
 
 /* ---------------------------------------------------------------------- */
