@@ -33,6 +33,8 @@
 -------------------------------------------------------------------------
     Contributing author and copyright for this file:
 
+    Alexander Podlozhnyuk (DCS Computing GmbH, Linz)
+    Andreas Aigner (DCS Computing GmbH, Linz)
     Christoph Kloss (DCS Computing GmbH, Linz)
     Christoph Kloss (JKU Linz)
     Richard Berger (JKU Linz)
@@ -49,7 +51,7 @@ ROLLING_MODEL(ROLLING_CDT,cdt,1)
 #include "contact_models.h"
 #include "rolling_model_base.h"
 #include <algorithm>
-#include <math.h>
+#include <cmath>
 #include "math_extra_liggghts.h"
 
 namespace LIGGGHTS {
@@ -96,12 +98,8 @@ namespace ContactModels
       double reff=sidata.is_wall ? radi : (radi*radj/(radi+radj));
 
 #ifdef SUPERQUADRIC_ACTIVE_FLAG
-      if(sidata.is_non_spherical) {
-        if(sidata.is_wall)
-          reff = MathExtraLiggghtsNonspherical::get_effective_radius_wall(sidata, atom->roundness[sidata.i], error);
-        else
-          reff = MathExtraLiggghtsNonspherical::get_effective_radius(sidata, atom->roundness[sidata.i], atom->roundness[sidata.j], error);
-      }
+      if(sidata.is_non_spherical && atom->superquadric_flag)
+        reff = sidata.reff;
 #endif
 
       if(sidata.is_wall){
