@@ -377,20 +377,57 @@ void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::calcSurfaceNorm(int nElem, double *su
     
     if(vectorMag3D(surfNorm) <1e-15)
     {
-        surfNorm[0] = - edgeVec(nElem)[0][1];
-        surfNorm[1] =   edgeVec(nElem)[0][0];
-        surfNorm[2] =   edgeVec(nElem)[0][2];
+        
+        vectorCross3D(edgeVec(nElem)[1],edgeVec(nElem)[2],surfNorm);
+        
+        if(vectorMag3D(surfNorm) <1e-15)
+        {
+            vectorCross3D(edgeVec(nElem)[2],edgeVec(nElem)[0],surfNorm);
+            
+            if(vectorMag3D(surfNorm) <1e-15)
+            {
+                double tmpvec[] = {1.1233,2.123231,-3.3343434};
+                vectorCross3D(edgeVec(nElem)[0],tmpvec,surfNorm);
+                
+                if(vectorMag3D(surfNorm) <1e-15)
+                {
+                    vectorCross3D(edgeVec(nElem)[1],tmpvec,surfNorm);
+                    
+                    if(vectorMag3D(surfNorm) <1e-15)
+                    {
+                        double tmpvec2[] = {1.1233,-2.123231,3.3343434};
+                        vectorCross3D(edgeVec(nElem)[0],tmpvec2,surfNorm);
+                        
+                        if(vectorMag3D(surfNorm) <1e-15)
+                        {
+                            vectorCross3D(edgeVec(nElem)[1],tmpvec2,surfNorm);
+                            
+                        }
+                    }
+                }
+            }
+        }
+        
     }
-    else
-        vectorScalarDiv3D(surfNorm, vectorMag3D(surfNorm));
+
+    vectorScalarDiv3D(surfNorm, vectorMag3D(surfNorm));
 }
 
 template<int NUM_NODES, int NUM_NEIGH_MAX>
 void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::calcEdgeNormals(int nElem, double **edgeNorm)
 {
-    for(int i=0;i<NUM_NODES;i++){
+    for(int i=0;i<NUM_NODES;i++)
+    {
       vectorCross3D(edgeVec(nElem)[i],surfaceNorm(nElem),edgeNorm[i]);
-      vectorScalarDiv3D(edgeNorm[i],vectorMag3D(edgeNorm[i]));
+
+      if(vectorMag3D(edgeNorm[i]) <1e-15)
+      {
+          int otherIndex = (i+1)%3;
+          vectorCopy3D(edgeVec(nElem)[otherIndex],edgeNorm[i]);
+          
+      }
+      else
+        vectorScalarDiv3D(edgeNorm[i],vectorMag3D(edgeNorm[i]));
     }
 }
 
@@ -419,6 +456,9 @@ void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::buildNeighbours()
     
     int nall = this->sizeLocal()+this->sizeGhost();
 
+    if (this->lmp->wb && this->comm->me == 0)
+        fprintf(this->screen,"\nBuilding mesh topology (mesh processing step 2/3) \n");
+
     bool t[NUM_NODES], f[NUM_NODES];
     int neighs[NUM_NEIGH_MAX];
 
@@ -461,7 +501,10 @@ void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::buildNeighbours()
 
         for (int i = 0; i < nall; ++i)
         {
-            
+            //useless since would need allreduce to work
+            //if (this->lmp->wb && this->comm->me == 0 && 0 == i % 100000)
+            //    fprintf(this->screen,"   successfully built for a chunk of 100000 mesh elements\n");
+
             overlaps.clear();
             neighList_.hasOverlapWith(this->center_(i), this->rBound_(i),overlaps);
 
@@ -496,7 +539,8 @@ void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::buildNeighbours()
             handleCorner(i,iNode,idListVisited,idListHasNode,edgeList,edgeEndPoint);
     }
 
-    handleExclusion(idListVisited);
+    if(MultiNodeMesh<NUM_NODES>::minFeatureLength() > 0. && MultiNodeMesh<NUM_NODES>::elementExclusionList())
+        handleExclusion(idListVisited);
 
     delete []idListVisited;
     delete []idListHasNode;
@@ -505,9 +549,10 @@ void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::buildNeighbours()
     
     fflush(MultiNodeMesh<NUM_NODES>::elementExclusionList());
 
-    // correct edge and corner activation/deactivation in parallel
+    // correct edge and corner activation/deactivation and neighs in parallel
     
-    parallelCorrection();
+    parallelCorrectionActiveInactive();
+    parallelCorrectionNeighs();
 
 }
 
@@ -518,7 +563,9 @@ void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::buildNeighbours()
 template<int NUM_NODES, int NUM_NEIGH_MAX>
 void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::qualityCheck()
 {
-    
+    if (this->lmp->wb && this->comm->me == 0)
+        fprintf(this->screen,"\nChecking quality of mesh (mesh processing step 3/3) \n");
+
     // iterate over surfaces
     
     int nlocal = this->sizeLocal();
@@ -547,6 +594,9 @@ void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::qualityCheck()
 
         for (int i = 0; i < nall; ++i)
         {
+            //useless since would need allreduce to work
+            //if (this->lmp->wb && this->comm->me == 0 && 0 == i % 100000)
+            //    fprintf(this->screen,"   successfully checked a chunk of 100000 mesh elements\n");
 
             overlaps.clear();
             neighList_.hasOverlapWith(this->center_(i), this->rBound_(i),overlaps);
@@ -657,10 +707,10 @@ void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::qualityCheck()
 ------------------------------------------------------------------------- */
 
 template<int NUM_NODES, int NUM_NEIGH_MAX>
-void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::parallelCorrection()
+void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::parallelCorrectionActiveInactive()
 {
     
-    int iGlobal,iLocal;
+    int iGlobal;
     int mine = this->sizeLocal()+this->sizeGhost();
     int sizeGlob = this->sizeGlobal();
     int len = NUM_NODES*sizeGlob;
@@ -676,8 +726,8 @@ void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::parallelCorrection()
 
         for(int j = 0; j < NUM_NODES; j++)
         {
-            edgea[iGlobal*NUM_NODES+j] = edgeActive(i)[j]?1:0;
-            cornera[iGlobal*NUM_NODES+j] = cornerActive(i)[j]?1:0;
+            edgea[iGlobal*NUM_NODES+j] = (edgeActive(i)[j] && edgea[iGlobal*NUM_NODES+j] > 0) ? 1 : 0;
+            cornera[iGlobal*NUM_NODES+j] = (cornerActive(i)[j] && cornera[iGlobal*NUM_NODES+j] > 0) ? 1 : 0;
         }
     }
 
@@ -686,23 +736,27 @@ void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::parallelCorrection()
 
     for(int i = 0; i < sizeGlob; i++)
     {
-        iLocal = this->map(i);
-        if(iLocal >= 0)
+        const int nTri_j = this->map_size(i);
+        for (int j = 0; j < nTri_j; j++)
         {
-            for(int j = 0; j < NUM_NODES; j++)
+            const int iLocal = this->map(i, j);
+            if(iLocal >= 0)
             {
-                if(edgea[i*NUM_NODES+j] == 0)
-                    edgeActive(iLocal)[j] = false;
-                else if(edgea[i*NUM_NODES+j] == 1)
-                    edgeActive(iLocal)[j] = true;
-                else
-                    this->error->one(FLERR,"Illegal situation in SurfaceMesh::parallelCorrection()");
-                if(cornera[i*NUM_NODES+j] == 0)
-                    cornerActive(iLocal)[j] = false;
-                else if(cornera[i*NUM_NODES+j] == 1)
-                    cornerActive(iLocal)[j] = true;
-                else
-                    this->error->one(FLERR,"Illegal situation in SurfaceMesh::parallelCorrection()");
+                for(int j = 0; j < NUM_NODES; j++)
+                {
+                    if(edgea[i*NUM_NODES+j] == 0)
+                        edgeActive(iLocal)[j] = false;
+                    else if(edgea[i*NUM_NODES+j] == 1)
+                        edgeActive(iLocal)[j] = true;
+                    else
+                        this->error->one(FLERR,"Illegal situation in SurfaceMesh::parallelCorrection()");
+                    if(cornera[i*NUM_NODES+j] == 0)
+                        cornerActive(iLocal)[j] = false;
+                    else if(cornera[i*NUM_NODES+j] == 1)
+                        cornerActive(iLocal)[j] = true;
+                    else
+                        this->error->one(FLERR,"Illegal situation in SurfaceMesh::parallelCorrection()");
+                }
             }
         }
     }
@@ -711,6 +765,77 @@ void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::parallelCorrection()
     delete []cornera;
 }
 
+/* ----------------------------------------------------------------------
+   correct neighs in parallel
+------------------------------------------------------------------------- */
+
+template<int NUM_NODES, int NUM_NEIGH_MAX>
+void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::parallelCorrectionNeighs()
+{
+    
+    int iGlobal;
+    int nlocal = this->sizeLocal();
+    int nghost = this->sizeGhost();
+    int sizeGlob = this->sizeGlobal();
+    int len1 = NUM_NEIGH_MAX*sizeGlob;
+    int len2 = sizeGlob;
+
+    int *neighs_found_by_owned_id = new int[len1];
+    vectorInitializeN(neighs_found_by_owned_id,len1,-1);
+
+    int *additionalNeigh_id = new int[len2];
+    vectorInitializeN(additionalNeigh_id,len2,-1);
+
+    for(int i = 0; i < nlocal; i++)
+    {
+        iGlobal = TrackingMesh<NUM_NODES>::id(i);
+
+        for(int iNeigh = 0; iNeigh< nNeighs_(i); iNeigh++)
+        {
+            neighs_found_by_owned_id[iGlobal*NUM_NEIGH_MAX+iNeigh] = neighFaces_(i)[iNeigh];
+        }
+    }
+
+    MPI_Max_Vector(neighs_found_by_owned_id,len1,this->world);
+
+    for(int i = nlocal; i < nlocal+nghost; i++)
+    {
+        iGlobal = TrackingMesh<NUM_NODES>::id(i);
+
+        for(int iNeigh = 0; iNeigh < nNeighs_(i); iNeigh++)
+        {
+            bool already_found = false;
+
+            for(int iFound = 0; iFound < NUM_NEIGH_MAX; iFound++)
+            {
+                if(neighs_found_by_owned_id[iGlobal*NUM_NEIGH_MAX+iFound] == neighFaces_(i)[iNeigh])
+                    already_found = true;
+            }
+
+            if(!already_found)
+                additionalNeigh_id[iGlobal] = neighFaces_(i)[iNeigh];
+        }
+    }
+
+    MPI_Max_Vector(additionalNeigh_id,len2,this->world);
+
+    for(int i = 0; i < nlocal; i++)
+    {
+        iGlobal = TrackingMesh<NUM_NODES>::id(i);
+
+        if(additionalNeigh_id[iGlobal] > -1)
+        {
+            // set neighbor topology
+            if(nNeighs_(i) < NUM_NEIGH_MAX)
+                neighFaces_(i)[nNeighs_(i)] = additionalNeigh_id[iGlobal] ;
+            nNeighs_(i)++;
+        }
+    }
+
+    delete []neighs_found_by_owned_id;
+    delete []additionalNeigh_id;
+}
+
 /* ----------------------------------------------------------------------
    functions to generate mesh topology
 ------------------------------------------------------------------------- */
@@ -718,8 +843,8 @@ void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::parallelCorrection()
 template<int NUM_NODES, int NUM_NEIGH_MAX>
 bool SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::areCoplanar(int tag_a, int tag_b)
 {
-    int a = this->map(tag_a);
-    int b = this->map(tag_b);
+    int a = this->map(tag_a, 0);
+    int b = this->map(tag_b, 0);
 
     if(a < 0 || b < 0)
         this->error->one(FLERR,"Internal error: Illegal call to SurfaceMesh::areCoplanar()");
@@ -739,8 +864,8 @@ template<int NUM_NODES, int NUM_NEIGH_MAX>
 bool SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::areCoplanarNeighs(int tag_a, int tag_b)
 {
     bool areNeighs = false;
-    int a = this->map(tag_a);
-    int b = this->map(tag_b);
+    int a = this->map(tag_a, 0);
+    int b = this->map(tag_b, 0);
 
     if(a < 0 || b < 0)
         this->error->one(FLERR,"Internal error: Illegal call to SurfaceMesh::areCoplanarNeighs()");
@@ -767,8 +892,8 @@ template<int NUM_NODES, int NUM_NEIGH_MAX>
 bool SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::areCoplanarNodeNeighs(int tag_a, int tag_b)
 {
     bool areNeighs = false;
-    int a = this->map(tag_a);
-    int b = this->map(tag_b);
+    int a = this->map(tag_a, 0);
+    int b = this->map(tag_b, 0);
 
     if(a < 0 || b < 0)
         this->error->one(FLERR,"Internal error: Illegal call to SurfaceMesh::areCoplanarNeighs()");
@@ -780,7 +905,22 @@ bool SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::areCoplanarNodeNeighs(int tag_a, int
         if(neighFaces_(a)[i] == tag_b)
             areNeighs = true;
 
-    if(!areNeighs && MultiNodeMesh<NUM_NODES>::nSharedNodes(a,b) == 0) return false;
+    const int nTri_j = this->map_size(tag_b);
+    bool found = false;
+    // only check if normals are equal if they are not listed as neigbors
+    if (!areNeighs)
+    {
+        for (int j = 0; j < nTri_j; j++)
+        {
+            const int b_tmp = this->map(tag_b, j);
+            if (MultiNodeMesh<NUM_NODES>::nSharedNodes(a,b_tmp) != 0)
+            {
+                found = true;
+                break;
+            }
+        }
+    }
+    if(!areNeighs && !found) return false;
 
     double dot = vectorDot3D(surfaceNorm(a),surfaceNorm(b));
     
@@ -875,12 +1015,12 @@ bool SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::shareEdge(int iSrf, int jSrf, int &iE
         iEdge = 2;
       
       else
-        iEdge = MathExtraLiggghts::min(iNode1,iNode2);
+        iEdge = std::min(iNode1,iNode2);
 
       if(2 == jNode1+jNode2)
         jEdge = 2;
       else
-        jEdge = MathExtraLiggghts::min(jNode1,jNode2);
+        jEdge = std::min(jNode1,jNode2);
 
       return true;
     }
@@ -933,6 +1073,7 @@ void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::handleSharedEdge(int iSrf, int iEdge,
             neighFaces_(jSrf)[nNeighs_(jSrf)] = TrackingMesh<NUM_NODES>::id(iSrf);
         nNeighs_(iSrf)++;
         nNeighs_(jSrf)++;
+
     }
 
     // deactivate one egde
@@ -977,12 +1118,15 @@ int SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::handleCorner(int iSrf, int iNode,
     checkNodeRecursive(iSrf,nodeToCheck,nIdListVisited,idListVisited,
         nIdListHasNode,idListHasNode,edgeList,edgeEndPoint,anyActiveEdge);
 
+    if (!this->domain->is_in_subdomain(nodeToCheck))
+        return nIdListHasNode;
+
     // each element that shares the node contributes two edges
     nEdgeList = 2*nIdListHasNode;
 
     // get max ID
     for(int i = 0; i < nIdListHasNode; i++)
-        maxId = MathExtraLiggghts::max(maxId,idListHasNode[i]);
+        maxId = std::max(maxId,idListHasNode[i]);
 
     // check if any 2 edges coplanar
     
@@ -1044,10 +1188,14 @@ void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::checkNodeRecursive(int iSrf,double *n
         {
             idNeigh = neighFaces_(iSrf)[iN];
             if(idNeigh < 0) return;
-            iNeigh = this->map(idNeigh);
-            if(iNeigh >= 0)
-                checkNodeRecursive(iNeigh,nodeToCheck,nIdListVisited,idListVisited,nIdListHasNode,
-                                    idListHasNode,edgeList,edgeEndPoint,anyActiveEdge);
+            const int nTri_j = this->map_size(idNeigh);
+            for (int j = 0; j < nTri_j; j++)
+            {
+                iNeigh = this->map(idNeigh, j);
+                if(iNeigh >= 0)
+                    checkNodeRecursive(iNeigh,nodeToCheck,nIdListVisited,idListVisited,nIdListHasNode,
+                                       idListHasNode,edgeList,edgeEndPoint,anyActiveEdge);
+            }
         }
     }
     
@@ -1058,13 +1206,13 @@ void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::checkNodeRecursive(int iSrf,double *n
 ------------------------------------------------------------------------- */
 
 template<int NUM_NODES, int NUM_NEIGH_MAX>
-void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::move(double *vecTotal, double *vecIncremental)
+void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::move(const double * const vecTotal, const double * const vecIncremental)
 {
     TrackingMesh<NUM_NODES>::move(vecTotal,vecIncremental);
 }
 
 template<int NUM_NODES, int NUM_NEIGH_MAX>
-void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::move(double *vecIncremental)
+void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::move(const double * const vecIncremental)
 {
     TrackingMesh<NUM_NODES>::move(vecIncremental);
 }
@@ -1085,7 +1233,7 @@ void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::scale(double factor)
 ------------------------------------------------------------------------- */
 
 template<int NUM_NODES, int NUM_NEIGH_MAX>
-void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::rotate(double *totalQ, double *dQ,double *origin)
+void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::rotate(const double * const totalQ, const double * const dQ, const double * const origin)
 {
     TrackingMesh<NUM_NODES>::rotate(totalQ,dQ,origin);
 
@@ -1095,7 +1243,7 @@ void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::rotate(double *totalQ, double *dQ,dou
 }
 
 template<int NUM_NODES, int NUM_NEIGH_MAX>
-void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::rotate(double *dQ,double *origin)
+void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::rotate(const double * const dQ, const double * const origin)
 {
     TrackingMesh<NUM_NODES>::rotate(dQ,origin);
 
@@ -1227,4 +1375,111 @@ double SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::edgePointDist(int iSrf, int iEdge,
             return MathExtraLiggghts::abs(vectorDot3D(edgeNorm(iSrf)[iEdge],nodeToP));
 }
 
+/* ----------------------------------------------------------------------
+    Extrude a planar mesh in direction of the normal by length
+------------------------------------------------------------------------- */
+
+template<int NUM_NODES, int NUM_NEIGH_MAX>
+void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::extrudePlanarMesh(const double length, double * &extrusion_tri_nodes, int &extrusion_tri_count)
+{
+    if(!this->isPlanar())
+        this->error->all(FLERR, "Cannot extrude non-planar mesh");
+
+    const int nlocal = this->sizeLocal();
+
+    if (nlocal == 0 && this->comm->nprocs == 1)
+        return;
+
+    double extrudeVec[3];
+    vectorCopy3D(surfaceNorm(0), extrudeVec);
+    vectorScalarMult3D(extrudeVec, -length);
+
+    extrusion_tri_count = 0;
+    for(int i = 0; i < nlocal; i++)
+        extrusion_tri_count += n_active_edges(i);
+    extrusion_tri_count *= 2;
+
+    // number of triangles local
+    int count_local = extrusion_tri_count;
+    // offset in nodes array for local proc
+    int offset = 0;
+    // number of tris for each processor
+    int *n_tris_proc = new int[this->comm->nprocs];
+    int *offsets_proc= new int[this->comm->nprocs];
+    if (this->comm->nprocs > 1)
+    {
+        // get number of triangles of each processor
+        MPI_Allgather(&count_local, 1, MPI_INT, &n_tris_proc[0], 1, MPI_INT, this->world);
+        // compute total number of triangles and offset
+        extrusion_tri_count = 0;
+        for (int i = 0; i < this->comm->nprocs; i++)
+        {
+            extrusion_tri_count += n_tris_proc[i];
+            if (i < this->comm->me)
+                offset += n_tris_proc[i];
+            // now this becomes the number of vector_components * nodes * triangles
+            n_tris_proc[i] *= 3*3;
+            if (i > 0)
+                offsets_proc[i] = offsets_proc[i-1] + n_tris_proc[i-1];
+            else
+                offsets_proc[i] = 0;
+        }
+    }
+
+    if (extrusion_tri_count == 0)
+        return;
+
+    offset *= 3;
+
+    // number of new triangles = number of active edges * 2 (for rectangle)
+    extrusion_tri_nodes = new double[extrusion_tri_count*3*3];
+    double * outbuf = new double[count_local*3*3];
+
+    // loop over all triangles
+    int count = 0;
+    for(int i = 0; i < nlocal; i++)
+    {
+        // check if which edges of it are active (i.e. are on the boundary)
+        // those will be extended along the normal by two triangles
+        for (int j = 0; j < NUM_NODES; j++)
+        {
+            if(edgeActive(i)[j])
+                extrudeEdge(i, j, extrudeVec, count, outbuf);
+        }
+    }
+
+    if (this->comm->nprocs > 1)
+        MPI_Allgatherv(outbuf, count_local*3*3, MPI_DOUBLE,
+                       &extrusion_tri_nodes[0], n_tris_proc, offsets_proc,
+                       MPI_DOUBLE, this->world);
+    else
+        vectorCopyN(outbuf, extrusion_tri_nodes, count_local*3*3);
+    delete[] outbuf;
+    delete[] n_tris_proc;
+    delete[] offsets_proc;
+}
+
+template<int NUM_NODES, int NUM_NEIGH_MAX>
+void SurfaceMesh<NUM_NODES,NUM_NEIGH_MAX>::extrudeEdge(const int nElem, const int edge, const double * const extrudeVec, int &count, double * extrusion_tri_nodes)
+{
+    vectorCopy3D(MultiNodeMesh<NUM_NODES>::node_(nElem)[(edge+1)%NUM_NODES],
+                 &extrusion_tri_nodes[count*3]);
+    count++;
+    vectorCopy3D(MultiNodeMesh<NUM_NODES>::node_(nElem)[edge],
+                 &extrusion_tri_nodes[count*3]);
+    count++;
+    vectorAdd3D(&extrusion_tri_nodes[(count-2)*3], extrudeVec,
+                &extrusion_tri_nodes[count*3]);
+    count++;
+    vectorCopy3D(&extrusion_tri_nodes[(count-2)*3],
+                 &extrusion_tri_nodes[count*3]);
+    count++;
+    vectorAdd3D(&extrusion_tri_nodes[(count-1)*3], extrudeVec,
+                &extrusion_tri_nodes[count*3]);
+    count++;
+    vectorCopy3D(&extrusion_tri_nodes[(count-3)*3],
+                 &extrusion_tri_nodes[count*3]);
+    count++;
+}
+
 #endif
