@@ -43,17 +43,41 @@
 
 #include <mpi.h>
 #include "lmptype.h"
-#include "lammps.h"
+#include "force.h"
 #include <string>
 #include <map>
 #include <iostream>
 #include "contact_interface.h"
+#include "contact_model_constants.h"
+#include <sstream>
 
 namespace LIGGGHTS {
 using namespace LAMMPS_NS;
 
 namespace Utils {
 
+  inline int64_t generate_gran_hashcode(int model, int tangential, int cohesion, int rolling, int surface)
+  {
+    return (((int64_t)model)           ) |
+           (((int64_t)tangential) <<  6) |
+           (((int64_t)cohesion)   << 12) |
+           (((int64_t)rolling)    << 18) |
+           (((int64_t)surface)    << 24) ;
+  }
+
+  inline std::string int_to_string(int a)
+  {
+    return static_cast< std::ostringstream & >(( std::ostringstream() << std::dec << a ) ).str();
+  }
+
+  inline std::string double_to_string(double dbl)
+  {
+    std::ostringstream strs;
+    strs << dbl;
+    std::string str = strs.str();
+    return str;
+  }
+
   template <typename T>
   inline T* ptr_reduce(T** &t)
   { return &(t[0][0]); }
@@ -69,8 +93,8 @@ namespace Utils {
   template<typename Interface>
   class AbstractFactory {
     typedef typename Interface::ParentType ParentType;
-    typedef Interface * (*Creator)(class LAMMPS * lmp, ParentType* parent);
-    typedef int64_t (*VariantSelector)(int & argc, char ** & argv);
+    typedef Interface * (*Creator)(class LAMMPS * lmp, ParentType* parent, int64_t hash);
+    typedef int64_t (*VariantSelector)(int & argc, char ** & argv, Custom_contact_models ccm);
     typedef std::map<std::pair<std::string, int>, Creator> StyleTable;
     typedef std::map<std::string, VariantSelector> VariantSelectorTable;
     StyleTable styleTable;
@@ -85,14 +109,19 @@ namespace Utils {
     Interface * create(const std::string & name, int64_t variant, class LAMMPS * lmp, ParentType* parent) {
       std::pair<std::string, int> key(name, variant);
       if(styleTable.find(key) != styleTable.end()) {
-        return styleTable[key](lmp, parent);
+        return styleTable[key](lmp, parent, variant);
+      }
+      int64_t default_variant = generate_gran_hashcode(ContactModels::NORMAL_OFF, ContactModels::TANGENTIAL_OFF, ContactModels::COHESION_OFF, ContactModels::ROLLING_OFF, 0);
+      std::pair<std::string, int> default_key(name, default_variant);
+      if(styleTable.find(default_key) != styleTable.end()) {
+        return styleTable[default_key](lmp, parent, variant);
       }
       return NULL;
     }
 
-    int64_t selectVariant(const std::string & name, int & argc, char ** & argv) {
+    int64_t selectVariant(const std::string & name, int & argc, char ** & argv,Custom_contact_models ccm) {
       if(variantSelectorTable.find(name) != variantSelectorTable.end()) {
-        return variantSelectorTable[name](argc, argv);
+        return variantSelectorTable[name](argc, argv,ccm);
       }
       return 0;
     }
