@@ -46,7 +46,7 @@
 #ifndef LMP_VARIABLE_H
 #define LMP_VARIABLE_H
 
-#include "stdlib.h"
+#include <stdlib.h>
 #include "pointers.h"
 
 namespace LAMMPS_NS {
